@@ -2,11 +2,8 @@
 #
 # Model.pm - Redland Perl RDF Model module
 #
-# $Id: Model.pm,v 1.42 2005/02/24 12:31:29 cmdjb Exp $
-#
-# Copyright (C) 2000-2003 David Beckett - http://purl.org/net/dajobe/
-# Institute for Learning and Research Technology - http://www.ilrt.org/
-# University of Bristol - http://www.bristol.ac.uk/
+# Copyright (C) 2000-2005 David Beckett - http://www.dajobe.org/
+# Copyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/
 # 
 # This package is Free Software or Open Source available under the
 # following licenses (these are alternatives):
@@ -651,7 +648,7 @@ L<RDF::Redland::Storage>, L<RDF::Redland::Node> and L<RDF::Redland::Statement>
 
 =head1 AUTHOR
 
-Dave Beckett - http://purl.org/net/dajobe/
+Dave Beckett - http://www.dajobe.org/
 
 =cut
 
