@@ -2,9 +2,7 @@
 #
 # Parser.pm - Redland Perl RDF Parser module
 #
-# $Id: Parser.pm 12210 2007-05-06 01:40:38Z dajobe $
-#
-# Copyright (C) 2000-2005 David Beckett - http://purl.org/net/dajobe/
+# Copyright (C) 2000-2005 David Beckett - http://www.dajobe.org/
 # Copyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/
 # 
 # This package is Free Software or Open Source available under the
@@ -209,15 +207,24 @@ returned.
 sub feature ($$;$) {
   my($self,$uri,$value)=@_;
 
-  warn "RDF::Redland::Parser->feature('$uri', '$value')\n" if $RDF::Redland::Debug;
+  warn "RDF::Redland::Parser->feature('$uri', '$value')\n"
+    if $RDF::Redland::Debug;
   $uri=RDF::Redland::URI->new($uri)
     unless ref $uri;
 
-  return &RDF::Redland::CORE::librdf_parser_set_feature($self->{PARSER},$uri->{URI},$value->{NODE})
-      if $value;
+  if(!defined $value) {
+    $value=&RDF::Redland::CORE::librdf_parser_get_feature($self->{PARSER},
+							  $uri->{URI});
+    return $value ? RDF::Redland::Node->_new_from_object($value,1) : undef;
+  }
+
+  $value=RDF::Redland::LiteralNode->new($value)
+    unless ref $value;
+
+  return &RDF::Redland::CORE::librdf_parser_set_feature($self->{PARSER},
+							$uri->{URI},
+							$value->{NODE})
 
-  $value=&RDF::Redland::CORE::librdf_parser_get_feature($self->{PARSER},$uri->{URI});
-  return $value ? RDF::Redland::Node->_new_from_object($value,1) : undef;
 }
 
 
@@ -254,7 +261,7 @@ L<RDF::Redland::URI>
 
 =head1 AUTHOR
 
-Dave Beckett - http://purl.org/net/dajobe/
+Dave Beckett - http://www.dajobe.org/
 
 =cut
 
