@@ -2,11 +2,8 @@
 #
 # Serializer.pm - Redland Perl RDF Serializer module
 #
-# $Id: Serializer.pm,v 1.9 2005/04/08 13:26:14 cmdjb Exp $
-#
-# Copyright (C) 2002-2005 David Beckett - http://purl.org/net/dajobe/
-# Institute for Learning and Research Technology - http://www.ilrt.org/
-# University of Bristol - http://www.bristol.ac.uk/
+# Copyright (C) 2002-2005 David Beckett - http://www.dajobe.org/
+# Copyright (C) 2002-2005 University of Bristol - http://www.bristol.ac.uk/
 # 
 # This package is Free Software or Open Source available under the
 # following licenses (these are alternatives):
@@ -154,14 +151,23 @@ is returned.
 sub feature ($$;$) {
   my($self,$uri,$value)=@_;
 
-  warn "RDF::Redland::Serializer->feature('$uri', '$value')\n" if $RDF::Redland::Debug;
+  warn "RDF::Redland::Serializer->feature('$uri', '$value')\n"
+    if $RDF::Redland::Debug;
   $uri=RDF::Redland::URI->new($uri)
     unless ref $uri;
 
-  return &RDF::Redland::CORE::librdf_serializer_get_feature($self->{SERIALIZER},$uri->{URI})
-    unless $value;
+  if(!defined $value) {
+    $value=&RDF::Redland::CORE::librdf_serializer_get_feature($self->{SERIALIZER},
+							      $uri->{URI});
+    return $value ? RDF::Redland::Node->_new_from_object($value,1) : undef;
+  }
 
-  return &RDF::Redland::CORE::librdf_serializer_set_feature($self->{SERIALIZER},$uri->{URI},$value);
+  $value=RDF::Redland::LiteralNode->new($value)
+    unless ref $value;
+
+  return &RDF::Redland::CORE::librdf_serializer_set_feature($self->{SERIALIZER},
+							    $uri->{URI},
+							    $value->{NODE});
 }
 
 
@@ -176,7 +182,7 @@ L<RDF::Redland::URI>
 
 =head1 AUTHOR
 
-Dave Beckett - http://purl.org/net/dajobe/
+Dave Beckett - http://www.dajobe.org/
 
 =cut
 
