@@ -2,9 +2,7 @@
 #
 # URINode.pm - Redland Perl RDF URI Node module
 #
-# $Id: URINode.pm 10593 2006-03-05 08:30:38Z dajobe $
-#
-# Copyright (C) 2005 David Beckett - http://purl.org/net/dajobe/
+# Copyright (C) 2005 David Beckett - http://www.dajobe.org/
 # Copyright (C) 2005 University of Bristol - http://www.bristol.ac.uk/
 # 
 # This package is Free Software or Open Source available under the
@@ -78,7 +76,7 @@ L<RDF::Redland::Node>
 
 =head1 AUTHOR
 
-Dave Beckett - http://purl.org/net/dajobe/
+Dave Beckett - http://www.dajobe.org/
 
 =cut
 
